pub enum PropertyType {
Simple(SimplePropertyType),
Color(ColorPropertyType),
}Expand description
A fixture property, either a simple single-channel attribute or a color.
- Simple(
SimplePropertyType) – Any non-color property such as dimmer, pan, gobo, etc. - Color(
ColorPropertyType) – A color channel (RGB, CMY, or HSV).
Variants
Simple(SimplePropertyType)
Color(ColorPropertyType)
Implementations
Sourceimpl PropertyType
impl PropertyType
Sourcepub fn from_str(property_type: &str) -> Result<PropertyType, FixtureError>
pub fn from_str(property_type: &str) -> Result<PropertyType, FixtureError>
Parses a raw string slice into a strongly typed PropertyType.
It sequentially attempts to match the input string against known ColorPropertyType
variants first, and then falls back to SimplePropertyType variants.
Arguments
property_type- A string slice representing the name of the property to parse.
Errors
Returns a InvalidPropertyType-Error if the string matches neither
a color nor a simple property.